@@ -66,9 +66,9 @@ static const char xdr_zero[BYTES_PER_XDR_UNIT] = { 0, 0, 0, 0 };
  * Not a filter, but a convenient utility nonetheless
  */
 void
-xdr_free(proc, objp)
-	xdrproc_t proc;
-	void *objp;
+xdr_free(
+	xdrproc_t proc,
+	void *objp)
 {
 	XDR x;
 	
@@ -91,9 +91,9 @@ xdr_void(void)
  * XDR integers
  */
 bool_t
-xdr_int(xdrs, ip)
-	XDR *xdrs;
-	int *ip;
+xdr_int(
+	XDR *xdrs,
+	int *ip)
 {
 	long l;
 
@@ -121,9 +121,9 @@ xdr_int(xdrs, ip)
  * XDR unsigned integers
  */
 bool_t
-xdr_u_int(xdrs, up)
-	XDR *xdrs;
-	u_int *up;
+xdr_u_int(
+	XDR *xdrs,
+	u_int *up)
 {
 	u_long l;
 
@@ -153,9 +153,9 @@ xdr_u_int(xdrs, up)
  * same as xdr_u_long - open coded to save a proc call!
  */
 bool_t
-xdr_long(xdrs, lp)
-	XDR *xdrs;
-	long *lp;
+xdr_long(
+	XDR *xdrs,
+	long *lp)
 {
 	switch (xdrs->x_op) {
 	case XDR_ENCODE:
@@ -174,9 +174,9 @@ xdr_long(xdrs, lp)
  * same as xdr_long - open coded to save a proc call!
  */
 bool_t
-xdr_u_long(xdrs, ulp)
-	XDR *xdrs;
-	u_long *ulp;
+xdr_u_long(
+	XDR *xdrs,
+	u_long *ulp)
 {
 	switch (xdrs->x_op) {
 	case XDR_ENCODE:
@@ -196,9 +196,9 @@ xdr_u_long(xdrs, ulp)
  * same as xdr_u_int32_t - open coded to save a proc call!
  */
 bool_t
-xdr_int32_t(xdrs, int32_p)
-	XDR *xdrs;
-	int32_t *int32_p;
+xdr_int32_t(
+	XDR *xdrs,
+	int32_t *int32_p)
 {
 	long l;
 
@@ -227,9 +227,9 @@ xdr_int32_t(xdrs, int32_p)
  * same as xdr_int32_t - open coded to save a proc call!
  */
 bool_t
-xdr_u_int32_t(xdrs, u_int32_p)
-	XDR *xdrs;
-	u_int32_t *u_int32_p;
+xdr_u_int32_t(
+	XDR *xdrs,
+	u_int32_t *u_int32_p)
 {
 	u_long l;
 
@@ -258,9 +258,9 @@ xdr_u_int32_t(xdrs, u_int32_p)
  * XDR unsigned 32-bit integers
  */
 bool_t
-xdr_uint32_t(xdrs, uint32_p)
-	XDR *xdrs;
-	uint32_t *uint32_p;
+xdr_uint32_t(
+	XDR *xdrs,
+	uint32_t *uint32_p)
 {
 	return (xdr_u_int32_t(xdrs, (u_int32_t *)uint32_p));
 }
@@ -270,9 +270,9 @@ xdr_uint32_t(xdrs, uint32_p)
  * XDR short integers
  */
 bool_t
-xdr_short(xdrs, sp)
-	XDR *xdrs;
-	short *sp;
+xdr_short(
+	XDR *xdrs,
+	short *sp)
 {
 	long l;
 
@@ -300,9 +300,9 @@ xdr_short(xdrs, sp)
  * XDR unsigned short integers
  */
 bool_t
-xdr_u_short(xdrs, usp)
-	XDR *xdrs;
-	u_short *usp;
+xdr_u_short(
+	XDR *xdrs,
+	u_short *usp)
 {
 	u_long l;
 
@@ -331,9 +331,9 @@ xdr_u_short(xdrs, usp)
  * XDR 16-bit integers
  */
 bool_t
-xdr_int16_t(xdrs, int16_p)
-	XDR *xdrs;
-	int16_t *int16_p;
+xdr_int16_t(
+	XDR *xdrs,
+	int16_t *int16_p)
 {
 	long l;
 
@@ -361,9 +361,9 @@ xdr_int16_t(xdrs, int16_p)
  * XDR unsigned 16-bit integers
  */
 bool_t
-xdr_u_int16_t(xdrs, u_int16_p)
-	XDR *xdrs;
-	u_int16_t *u_int16_p;
+xdr_u_int16_t(
+	XDR *xdrs,
+	u_int16_t *u_int16_p)
 {
 	u_long l;
 
@@ -392,9 +392,9 @@ xdr_u_int16_t(xdrs, u_int16_p)
  * XDR unsigned 16-bit integers
  */
 bool_t
-xdr_uint16_t(xdrs, uint16_p)
-	XDR *xdrs;
-	uint16_t *uint16_p;
+xdr_uint16_t(
+	XDR *xdrs,
+	uint16_t *uint16_p)
 {
 	return (xdr_u_int16_t(xdrs, (u_int16_t *)uint16_p));
 }
@@ -404,9 +404,9 @@ xdr_uint16_t(xdrs, uint16_p)
  * XDR 8-bit integers
  */
 bool_t
-xdr_int8_t(xdrs, int8_p)
-	XDR *xdrs;
-	int8_t *int8_p;
+xdr_int8_t(
+	XDR *xdrs,
+	int8_t *int8_p)
 {
 	long l;
 
@@ -435,9 +435,9 @@ xdr_int8_t(xdrs, int8_p)
  * XDR unsigned 8-bit integers
  */
 bool_t
-xdr_u_int8_t(xdrs, uint8_p)
-	XDR *xdrs;
-	uint8_t *uint8_p;
+xdr_u_int8_t(
+	XDR *xdrs,
+	uint8_t *uint8_p)
 {
 	u_long l;
 
@@ -466,9 +466,9 @@ xdr_u_int8_t(xdrs, uint8_p)
  * XDR unsigned 8-bit integers
  */
 bool_t
-xdr_uint8_t(xdrs, uint8_p)
-	XDR *xdrs;
-	uint8_t *uint8_p;
+xdr_uint8_t(
+	XDR *xdrs,
+	uint8_t *uint8_p)
 {
 	return (xdr_u_int8_t(xdrs, (uint8_t *)uint8_p));
 }
@@ -478,9 +478,9 @@ xdr_uint8_t(xdrs, uint8_p)
  * XDR a char
  */
 bool_t
-xdr_char(xdrs, cp)
-	XDR *xdrs;
-	char *cp;
+xdr_char(
+	XDR *xdrs,
+	char *cp)
 {
 	int i;
 
@@ -496,9 +496,9 @@ xdr_char(xdrs, cp)
  * XDR an unsigned char
  */
 bool_t
-xdr_u_char(xdrs, cp)
-	XDR *xdrs;
-	u_char *cp;
+xdr_u_char(
+	XDR *xdrs,
+	u_char *cp)
 {
 	u_int u;
 
@@ -514,9 +514,9 @@ xdr_u_char(xdrs, cp)
  * XDR booleans
  */
 bool_t
-xdr_bool(xdrs, bp)
-	XDR *xdrs;
-	bool_t *bp;
+xdr_bool(
+	XDR *xdrs,
+	bool_t *bp)
 {
 	long lb;
 
@@ -544,9 +544,9 @@ xdr_bool(xdrs, bp)
  * XDR enumerations
  */
 bool_t
-xdr_enum(xdrs, ep)
-	XDR *xdrs;
-	enum_t *ep;
+xdr_enum(
+	XDR *xdrs,
+	enum_t *ep)
 {
 	enum sizecheck { SIZEVAL };	/* used to find the size of an enum */
 
@@ -570,10 +570,10 @@ xdr_enum(xdrs, ep)
  * cp points to the opaque object and cnt gives the byte length.
  */
 bool_t
-xdr_opaque(xdrs, cp, cnt)
-	XDR *xdrs;
-	caddr_t cp;
-	u_int cnt;
+xdr_opaque(
+	XDR *xdrs,
+	caddr_t cp,
+	u_int cnt)
 {
 	u_int rndup;
 	static int crud[BYTES_PER_XDR_UNIT];
@@ -622,11 +622,11 @@ xdr_opaque(xdrs, cp, cnt)
  * If *cpp is NULL maxsize bytes are allocated
  */
 bool_t
-xdr_bytes(xdrs, cpp, sizep, maxsize)
-	XDR *xdrs;
-	char **cpp;
-	u_int *sizep;
-	u_int maxsize;
+xdr_bytes(
+	XDR *xdrs,
+	char **cpp,
+	u_int *sizep,
+	u_int maxsize)
 {
 	char *sp = *cpp;  /* sp is the actual string pointer */
 	u_int nodesize;
@@ -687,9 +687,9 @@ xdr_bytes(xdrs, cpp, sizep, maxsize)
  * Implemented here due to commonality of the object.
  */
 bool_t
-xdr_netobj(xdrs, np)
-	XDR *xdrs;
-	struct netobj *np;
+xdr_netobj(
+	XDR *xdrs,
+	struct netobj *np)
 {
 
 	return (xdr_bytes(xdrs, &np->n_bytes, &np->n_len, MAX_NETOBJ_SZ));
@@ -707,12 +707,12 @@ xdr_netobj(xdrs, np)
  * If there is no specific or default routine an error is returned.
  */
 bool_t
-xdr_union(xdrs, dscmp, unp, choices, dfault)
-	XDR *xdrs;
-	enum_t *dscmp;		/* enum to decide which arm to work on */
-	char *unp;		/* the union itself */
-	const struct xdr_discrim *choices;	/* [value, xdr proc] for each arm */
-	xdrproc_t dfault;	/* default xdr routine */
+xdr_union(
+	XDR *xdrs,
+	enum_t *dscmp,		/* enum to decide which arm to work on */
+	char *unp,		/* the union itself */
+	const struct xdr_discrim *choices,	/* [value, xdr proc] for each arm */
+	xdrproc_t dfault)	/* default xdr routine */
 {
 	enum_t dscm;
 
@@ -756,10 +756,10 @@ xdr_union(xdrs, dscmp, unp, choices, dfault)
  * of the string as specified by a protocol.
  */
 bool_t
-xdr_string(xdrs, cpp, maxsize)
-	XDR *xdrs;
-	char **cpp;
-	u_int maxsize;
+xdr_string(
+	XDR *xdrs,
+	char **cpp,
+	u_int maxsize)
 {
 	char *sp = *cpp;  /* sp is the actual string pointer */
 	u_int size;
@@ -839,9 +839,9 @@ xdr_string(xdrs, cpp, maxsize)
  * routines like clnt_call
  */
 bool_t
-xdr_wrapstring(xdrs, cpp)
-	XDR *xdrs;
-	char **cpp;
+xdr_wrapstring(
+	XDR *xdrs,
+	char **cpp)
 {
 	return xdr_string(xdrs, cpp, RPC_MAXDATASIZE);
 }
@@ -858,9 +858,9 @@ xdr_wrapstring(xdrs, cpp)
  * XDR 64-bit integers
  */
 bool_t
-xdr_int64_t(xdrs, llp)
-	XDR *xdrs;
-	int64_t *llp;
+xdr_int64_t(
+	XDR *xdrs,
+	int64_t *llp)
 {
 	u_long ul[2];
 
@@ -892,9 +892,9 @@ xdr_int64_t(xdrs, llp)
  * XDR unsigned 64-bit integers
  */
 bool_t
-xdr_u_int64_t(xdrs, ullp)
-	XDR *xdrs;
-	u_int64_t *ullp;
+xdr_u_int64_t(
+	XDR *xdrs,
+	u_int64_t *ullp)
 {
 	u_long ul[2];
 
@@ -926,9 +926,9 @@ xdr_u_int64_t(xdrs, ullp)
  * XDR unsigned 64-bit integers
  */
 bool_t
-xdr_uint64_t(xdrs, ullp)
-	XDR *xdrs;
-	uint64_t *ullp;
+xdr_uint64_t(
+	XDR *xdrs,
+	uint64_t *ullp)
 {
 	return (xdr_u_int64_t(xdrs, (u_int64_t *)ullp));
 }
@@ -938,9 +938,9 @@ xdr_uint64_t(xdrs, ullp)
  * XDR hypers
  */
 bool_t
-xdr_hyper(xdrs, llp)
-	XDR *xdrs;
-	longlong_t *llp;
+xdr_hyper(
+	XDR *xdrs,
+	longlong_t *llp)
 {
 
 	/*
@@ -955,9 +955,9 @@ xdr_hyper(xdrs, llp)
  * XDR unsigned hypers
  */
 bool_t
-xdr_u_hyper(xdrs, ullp)
-	XDR *xdrs;
-	u_longlong_t *ullp;
+xdr_u_hyper(
+	XDR *xdrs,
+	u_longlong_t *ullp)
 {
 
 	/*
@@ -972,9 +972,9 @@ xdr_u_hyper(xdrs, ullp)
  * XDR longlong_t's
  */
 bool_t
-xdr_longlong_t(xdrs, llp)
-	XDR *xdrs;
-	longlong_t *llp;
+xdr_longlong_t(
+	XDR *xdrs,
+	longlong_t *llp)
 {
 
 	/*
@@ -989,9 +989,9 @@ xdr_longlong_t(xdrs, llp)
  * XDR u_longlong_t's
  */
 bool_t
-xdr_u_longlong_t(xdrs, ullp)
-	XDR *xdrs;
-	u_longlong_t *ullp;
+xdr_u_longlong_t(
+	XDR *xdrs,
+	u_longlong_t *ullp)
 {
 
 	/*
@@ -1005,9 +1005,9 @@ xdr_u_longlong_t(xdrs, ullp)
  * XDR quad_t
  */
 bool_t
-xdr_quad_t(xdrs, llp)
-	XDR *xdrs;
-	int64_t *llp;
+xdr_quad_t(
+	XDR *xdrs,
+	int64_t *llp)
 {
 	return (xdr_int64_t(xdrs, (int64_t *)llp));
 }
@@ -1017,9 +1017,9 @@ xdr_quad_t(xdrs, llp)
  * XDR u_quad_t
  */
 bool_t
-xdr_u_quad_t(xdrs, ullp)
-	XDR *xdrs;
-	u_int64_t *ullp;
+xdr_u_quad_t(
+	XDR *xdrs,
+	u_int64_t *ullp)
 {
 	return (xdr_u_int64_t(xdrs, (u_int64_t *)ullp));
 }
